@@ -3,7 +3,7 @@ export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bi
 echo 'name: text-binary
 version: 0.2.1
 id: text-binary-0.2.1-5d724e6255914e391bee90b30a4cef13
-key: textb_5xO4Kn0BBaFJNvYNqRI029
+key: textb_KioNeiU611EIT91hPPFrob
 license: BSD3
 maintainer: waszczuk.kuba@gmail.com
 stability: provisional
@@ -22,11 +22,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/text-binary-0.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/text-binary-0.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/text-binary-0.2.1
-hs-libraries: HStext-binary-0.2.1-5xO4Kn0BBaFJNvYNqRI029
+hs-libraries: HStext-binary-0.2.1-KioNeiU611EIT91hPPFrob
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-text-binary/html/text-binary.haddock
 haddock-html: /usr/share/doc/haskell-text-binary/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
